@@ -8,3 +8,11 @@ def sql_entries(sql_result, headers=False):
         headers = [x[0] for x in sql_result.description]
         return headers, rows
     return rows
+
+
+def close_con_and_cur(con, cur, commit=True):
+    """Cleans up after a command is run"""
+    cur.close()
+    if commit:
+        con.commit()
+    con.close()
