@@ -1,40 +1,39 @@
 """usda.sqlite functions module"""
-from . import _sql
-
+from ntclient.persistence.sql.usda import _sql
 
 # ----------------------
 # USDA  functions
 # ----------------------
 
 
-def fdgrp():
+def sql_fdgrp():
     """Shows food groups"""
     query = "SELECT * FROM fdgrp;"
     result = _sql(query)
     return {x[0]: x for x in result}
 
 
-def food_details(food_ids):
+def sql_food_details(food_ids):
     """Readable human details for foods"""
     query = "SELECT * FROM food_des WHERE id IN (%s)"
     food_ids = ",".join(str(x) for x in set(food_ids))
     return _sql(query % food_ids)
 
 
-def nutrients_overview():
+def sql_nutrients_overview():
     """Shows nutrients overview"""
     query = "SELECT * FROM nutrients_overview;"
     result = _sql(query)
     return {x[0]: x for x in result}
 
 
-def nutrients_details():
+def sql_nutrients_details():
     """Shows nutrients 'details'"""
     query = "SELECT * FROM nutrients_overview;"
     return _sql(query, headers=True)
 
 
-def servings(food_ids):
+def sql_servings(food_ids):
     """Food servings"""
     # TODO: apply connective logic from `sort_foods()` IS ('None') ?
     query = """
@@ -53,7 +52,7 @@ WHERE
     return _sql(query % food_ids)
 
 
-def analyze_foods(food_ids):
+def sql_analyze_foods(food_ids):
     """Nutrient analysis for foods"""
     query = """
 SELECT
@@ -70,7 +69,7 @@ WHERE
     return _sql(query % food_ids)
 
 
-def sort_foods(nutr_id, fdgrp_ids=None):
+def sql_sort_foods(nutr_id):
     """Sort foods by nutr_id per 100 g"""
     query = """
 SELECT
@@ -87,20 +86,14 @@ FROM
   LEFT JOIN nut_data kcal ON food.id = kcal.food_id
     AND kcal.nutr_id = 208
 WHERE
-  nut_data.nutr_id = {0}"""
-    if fdgrp_ids:
-        query += """
-  AND (fdgrp_id IN ({1}))"""
-    query += """
+  nut_data.nutr_id = %s
 ORDER BY
-  nut_data.nutr_val DESC;"""
-    if fdgrp_ids:
-        fdgrp_ids = ",".join([str(x) for x in set(fdgrp_ids)])
-        return _sql(query.format(nutr_id, fdgrp_ids))
-    return _sql(query.format(nutr_id))
+  nut_data.nutr_val DESC;
+"""
+    return _sql(query % nutr_id)
 
 
-def sort_foods_by_kcal(nutr_id, fdgrp_ids=None):
+def sql_sort_foods_by_kcal(nutr_id):
     """Sort foods by nutr_id per 200 kcal"""
     query = """
 SELECT
@@ -119,14 +112,8 @@ FROM
     AND kcal.nutr_id = 208
     AND kcal.nutr_val > 0
 WHERE
-  nut_data.nutr_id = {0}"""
-    if fdgrp_ids:
-        query += """
-  AND (fdgrp_id IN ({1}))"""
-    query += """
+  nut_data.nutr_id = %s
 ORDER BY
-  (nut_data.nutr_val / kcal.nutr_val) DESC;"""
-    if fdgrp_ids:
-        fdgrp_ids = ",".join([str(x) for x in set(fdgrp_ids)])
-        return _sql(query.format(nutr_id, fdgrp_ids))
-    return _sql(query.format(nutr_id))
+  (nut_data.nutr_val / kcal.nutr_val) DESC;
+"""
+    return _sql(query % nutr_id)
