@@ -27,11 +27,18 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import csv
 import shutil
+from collections import OrderedDict
 
 from colorama import Fore, Style
 from tabulate import tabulate
 
-from ..utils import (
+from ntclient.persistence.sql.usda.funcs import (
+    sql_analyze_foods,
+    sql_food_details,
+    sql_nutrients_overview,
+    sql_servings,
+)
+from ntclient.utils import (
     COLOR_CRIT,
     COLOR_DEFAULT,
     COLOR_OVER,
@@ -45,20 +52,13 @@ from ..utils import (
     THRESH_OVER,
     THRESH_WARN,
 )
-from ..persistence import VERBOSITY
-from ..persistence.sql.usda.funcs import (
-    analyze_foods,
-    food_details,
-    nutrients_overview,
-    servings,
-)
 
 
 def foods_analyze(food_ids, grams=None):
     """Analyze a list of food_ids against stock RDA values"""
-    # TODO: from ..utils.nutprogbar import nutprogbar
+    # TODO: from ntclient.utils.nutprogbar import nutprogbar
     # Get analysis
-    raw_analyses = analyze_foods(food_ids)
+    raw_analyses = sql_analyze_foods(food_ids)
     analyses = {}
     for analysis in raw_analyses:
         food_id = analysis[0]
@@ -71,10 +71,10 @@ def foods_analyze(food_ids, grams=None):
         else:
             analyses[food_id].append(anl)
     # serving = servings()[1]
-    serving = servings(food_ids)
-    food_des = food_details(food_ids)
+    serving = sql_servings(food_ids)
+    food_des = sql_food_details(food_ids)
     food_des = {x[0]: x for x in food_des}
-    nutrients = nutrients_overview()
+    nutrients = sql_nutrients_overview()
     rdas = {x[0]: x[1] for x in nutrients.values()}
 
     # --------------------------------------
@@ -87,8 +87,8 @@ def foods_analyze(food_ids, grams=None):
         # food_name = food["long_desc"]
         print(
             "\n======================================\n"
-            f"==> {food_name} ({food_id})\n"
-            "======================================\n",
+            + "==> {0} ({1})\n".format(food_name, food_id)
+            + "======================================\n"
         )
         print("\n=========================\nSERVINGS\n=========================\n")
 
@@ -110,7 +110,7 @@ def foods_analyze(food_ids, grams=None):
         if refuse:
             print("\n=========================\nREFUSE\n=========================\n")
             print(refuse[0])
-            print(f"    ({refuse[1]}%, by mass)")
+            print("    ({0}%, by mass)".format(refuse[1]))
 
         print("\n=========================\nNUTRITION\n=========================\n")
 
@@ -151,26 +151,26 @@ def foods_analyze(food_ids, grams=None):
     return nutrients_tables, servings_tables
 
 
-def day_analyze(day_csv_paths, rda_csv_path=None):
+def day_analyze(day_csv_paths, rda_csv_path=None, debug=False):
     """Analyze a day optionally with custom RDAs,
     e.g.  nutra day ~/.nutra/rocky.csv -r ~/.nutra/dog-rdas-18lbs.csv
     TODO: Should be a subset of foods_analyze
     """
-    rdas = []
-    if rda_csv_path:
+    if rda_csv_path is not None:
         with open(rda_csv_path) as file_path:
             rda_csv_input = csv.DictReader(
                 row for row in file_path if not row.startswith("#")
             )
             rdas = list(rda_csv_input)
+    else:
+        rdas = []
 
     logs = []
     food_ids = set()
     for day_csv_path in day_csv_paths:
         with open(day_csv_path) as file_path:
-            day_csv_input = csv.DictReader(
-                row for row in file_path if not row.startswith("#")
-            )
+            rows = [row for row in file_path if not row.startswith("#")]
+            day_csv_input = csv.DictReader(rows)
             log = list(day_csv_input)
         for entry in log:
             if entry["id"]:
@@ -178,23 +178,21 @@ def day_analyze(day_csv_paths, rda_csv_path=None):
         logs.append(log)
 
     # Inject user RDAs
-    nutrients = [list(x) for x in nutrients_overview().values()]
+    nutrients = [tuple(x) for x in sql_nutrients_overview().values()]
     for rda in rdas:
         nutrient_id = int(rda["id"])
         _rda = float(rda["rda"])
         for nutrient in nutrients:
             if nutrient[0] == nutrient_id:
                 nutrient[1] = _rda
-                if VERBOSITY > 1:
-                    print(
-                        f"INJECT RDA: {f'{_rda} {nutrient[2]}'.ljust(12)} -->  {nutrient[4]}"
-                    )
+                if debug:
+                    substr = "{0} {1}".format(_rda, nutrient[2]).ljust(12)
+                    print("INJECT RDA: {0} -->  {1}".format(substr, nutrient[4]))
     nutrients = {x[0]: x for x in nutrients}
 
     # Analyze foods
-    _foods_analysis = analyze_foods(food_ids)
     foods_analysis = {}
-    for food in _foods_analysis:
+    for food in sql_analyze_foods(food_ids):
         food_id = food[0]
         anl = food[1], food[2]
         if food_id not in foods_analysis:
@@ -205,11 +203,9 @@ def day_analyze(day_csv_paths, rda_csv_path=None):
     # Compute totals
     nutrients_totals = []
     for log in logs:
-        nutrient_totals = {}
+        nutrient_totals = OrderedDict()
         for entry in log:
             if entry["id"]:
-                # TODO: was this broken with pycharm/pylint refactoring?
-                #  Is it log_id or nutrient_id?
                 food_id = int(entry["id"])
                 grams = float(entry["grams"])
                 for nutrient in foods_analysis[food_id]:
@@ -237,7 +233,7 @@ def day_format(analysis, nutrients, buffer=None):
     def print_header(header):
         print(Fore.CYAN, end="")
         print("~~~~~~~~~~~~~~~~~~~~~~~~~~~")
-        print(f"→ {header}")
+        print("--> %s" % header)
         print("~~~~~~~~~~~~~~~~~~~~~~~~~~~")
         print(Style.RESET_ALL)
 
@@ -259,7 +255,14 @@ def day_format(analysis, nutrients, buffer=None):
         c_buf = " " * (n_carb // 2) + "Carbs" + " " * (n_carb - n_carb // 2 - 5)
         p_buf = " " * (n_pro // 2) + "Pro" + " " * (n_pro - n_pro // 2 - 3)
         print(
-            f"  {Fore.YELLOW}{f_buf}{Fore.BLUE}{c_buf}{Fore.RED}{p_buf}{Style.RESET_ALL}"
+            "  "
+            + Fore.YELLOW
+            + f_buf
+            + Fore.BLUE
+            + c_buf
+            + Fore.RED
+            + p_buf
+            + Style.RESET_ALL
         )
 
         # Bars
@@ -279,7 +282,14 @@ def day_format(analysis, nutrients, buffer=None):
         )
         p_buf = " " * (n_pro // 2) + k_pro + " " * (n_pro - n_pro // 2 - len(k_pro))
         print(
-            f"  {Fore.YELLOW}{f_buf}{Fore.BLUE}{c_buf}{Fore.RED}{p_buf}{Style.RESET_ALL}"
+            "  "
+            + Fore.YELLOW
+            + f_buf
+            + Fore.BLUE
+            + c_buf
+            + Fore.RED
+            + p_buf
+            + Style.RESET_ALL
         )
 
     def print_nute_bar(n_id, amount, nutrients):
@@ -304,16 +314,16 @@ def day_format(analysis, nutrients, buffer=None):
             color = COLOR_DEFAULT
 
         # Print
-        detail_amount = f"{round(amount, 1)}/{rda} {unit}".ljust(18)
-        detail_amount = f"{detail_amount} -- {tag}"
+        detail_amount = "{0}/{1} {2}".format(round(amount, 1), rda, unit).ljust(18)
+        detail_amount = "{0} -- {1}".format(detail_amount, tag)
         left_index = 20
         left_pos = round(left_index * attain) if attain < 1 else left_index
-        print(f" {color}<", end="")
+        print(" {0}<".format(color), end="")
         print("=" * left_pos + " " * (left_index - left_pos) + ">", end="")
-        print(f" {perc}%\t[{detail_amount}]", end="")
+        print(" {0}%\t[{1}]".format(perc, detail_amount), end="")
         print(Style.RESET_ALL)
 
-        return (True,)
+        return True, perc
 
     # Actual values
     kcals = round(analysis[NUTR_ID_KCAL])
@@ -331,11 +341,18 @@ def day_format(analysis, nutrients, buffer=None):
     # Print calories and macronutrient bars
     print_header("Macronutrients")
     kcals_max = max(kcals, kcals_rda)
+    rda_perc = round(kcals * 100 / kcals_rda, 1)
     print(
-        f"Actual:    {kcals} kcal ({round(kcals * 100 / kcals_rda, 1)}% RDA), {kcals_449} by 4-4-9"
+        "Actual:    {0} kcal ({1}% RDA), {2} by 4-4-9".format(
+            kcals, rda_perc, kcals_449
+        )
     )
     print_macro_bar(fat, net_carb, pro, kcals_max, buffer=buffer)
-    print(f"\nDesired:   {kcals_rda} kcal ({'%+d' % (kcals - kcals_rda)} kcal)")
+    print(
+        "\nDesired:   {0} kcal ({1} kcal)".format(
+            kcals_rda, "%+d" % (kcals - kcals_rda)
+        )
+    )
     print_macro_bar(
         fat_rda,
         net_carb_rda,
