@@ -1,8 +1,8 @@
 """Biometrics SQL functions"""
 from tabulate import tabulate
 
-from ..persistence import PROFILE_ID
-from ..persistence.sql.nt.funcs import (
+from ntclient.persistence import PROFILE_ID
+from ntclient.persistence.sql.nt.funcs import (
     sql_biometric_add,
     sql_biometric_logs,
     sql_biometrics,
