@@ -27,29 +27,28 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import shutil
 
-from fuzzywuzzy import fuzz
 from tabulate import tabulate
 
-from ..utils import (
+from ntclient.persistence.sql.usda.funcs import (
+    _sql,
+    sql_analyze_foods,
+    sql_nutrients_details,
+    sql_nutrients_overview,
+    sql_sort_foods,
+    sql_sort_foods_by_kcal,
+)
+from ntclient.utils import (
     FOOD_NAME_TRUNC,
     NUTR_ID_KCAL,
     NUTR_IDS_AMINOS,
     NUTR_IDS_FLAVONES,
     SEARCH_LIMIT,
 )
-from ..persistence.sql.usda.funcs import (
-    _sql,
-    analyze_foods,
-    nutrients_details,
-    nutrients_overview,
-    sort_foods,
-    sort_foods_by_kcal,
-)
 
 
 def list_nutrients():
     """Lists out nutrients with basic details"""
-    headers, nutrients = nutrients_details()
+    headers, nutrients = sql_nutrients_details()
     # TODO: include in SQL table cache?
     headers.append("avg_rda")
     nutrients = [list(x) for x in nutrients]
@@ -76,35 +75,34 @@ def truncate_results(results):
 
 def print_results(results, nutrient_id):
     """Prints truncated list for sort"""
-    nutrients = nutrients_overview()
+    nutrients = sql_nutrients_overview()
     nutrient = nutrients[nutrient_id]
     unit = nutrient[2]
 
-    headers = ["food", "fdgrp", f"val ({unit})", "kcal", "long_desc"]
+    headers = ["food", "fdgrp", "val (%s)" % unit, "kcal", "long_desc"]
 
     table = tabulate(results, headers=headers, tablefmt="simple")
     print(table)
     return results
 
 
-def sort_foods_by_nutrient_id(nutrient_id):
-    """Default sort, by amount / 100 g"""
-    # TODO: sub shrt_desc for long if available, and support FOOD_NAME_TRUNC
-    results = truncate_results(sort_foods(nutrient_id))
-    return print_results(results, nutrient_id)
-
-
-def sort_foods_by_kcal_nutrient_id(nutrient_id):
-    """Caloric-weighted sort, by amount / 200 kcal"""
-    results = truncate_results(sort_foods_by_kcal(nutrient_id))
+def sort_foods_by_nutrient_id(nutrient_id, by_kcal):
+    """Sort, by nutrient, either (amount / 100 g) or (amount / 200 kcal)"""
+    # TODO: sub shrt_desc for long if available, and support config.FOOD_NAME_TRUNC
+    if by_kcal:
+        results = truncate_results(sql_sort_foods_by_kcal(nutrient_id))
+    else:
+        results = truncate_results(sql_sort_foods(nutrient_id))
     return print_results(results, nutrient_id)
 
 
 # -------------------------
 # Search
 # -------------------------
-def search_results(words):
+def search(words):
     """Searches foods for input"""
+    from fuzzywuzzy import fuzz  # pylint: disable=import-outside-toplevel
+
     food_des = _sql("SELECT * FROM food_des;")
 
     query = " ".join(words)
@@ -112,7 +110,7 @@ def search_results(words):
     scores = sorted(scores.items(), key=lambda x: x[1], reverse=True)[:SEARCH_LIMIT]
 
     food_ids = [s[0] for s in scores]
-    nut_data = analyze_foods(food_ids)
+    nut_data = sql_analyze_foods(food_ids)
 
     # Tally foods
     foods_nutrients = {}
@@ -122,30 +120,35 @@ def search_results(words):
         else:
             foods_nutrients[food_id][nutr_id] = nutr_val
 
+    def search_results(_scores):
+        """Generates search results, consumable by tabulate"""
+        _results = []
+        for score in _scores:
+            _food_id = score[0]
+            score = score[1]
+
+            food = food_des[_food_id]
+            fdgrp_id = food[1]
+            long_desc = food[2]
+            shrt_desc = food[3]
+
+            nutrients = foods_nutrients[_food_id]
+            result = {
+                "food_id": _food_id,
+                "fdgrp_id": fdgrp_id,
+                # TODO: get more details from another function, maybe enhance food_details() ?
+                # "fdgrp_desc": cache.fdgrp[fdgrp_id]["fdgrp_desc"],
+                # "data_src": cache.data_src[data_src_id]["name"],
+                "long_desc": shrt_desc if shrt_desc else long_desc,
+                "score": score,
+                "nutrients": nutrients,
+            }
+            _results.append(result)
+        return _results
+
     # TODO: include C/F/P macro ratios as column?
-    results = []
     food_des = {f[0]: f for f in food_des}
-    for score in scores:
-        food_id = score[0]
-        score = score[1]
-
-        food = food_des[food_id]
-        fdgrp_id = food[1]
-        long_desc = food[2]
-        shrt_desc = food[3]
-
-        nutrients = foods_nutrients[food_id]
-        result = {
-            "food_id": food_id,
-            "fdgrp_id": fdgrp_id,
-            # TODO: get more details from another function, maybe enhance food_details() ?
-            # "fdgrp_desc": cache.fdgrp[fdgrp_id]["fdgrp_desc"],
-            # "data_src": cache.data_src[data_src_id]["name"],
-            "long_desc": shrt_desc if shrt_desc else long_desc,
-            "score": score,
-            "nutrients": nutrients,
-        }
-        results.append(result)
+    results = search_results(scores)
 
     tabulate_search(results)
 
