@@ -27,12 +27,10 @@ along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 import pytest
 
-from .. import __db_target_nt__, __db_target_usda__
-from ..persistence.sql.nt import funcs as nt_funcs
-from ..persistence.sql.nt import nt_ver
-from ..persistence.sql.usda import funcs as usda_funcs
-from ..persistence.sql.usda import usda_ver
-from ..services import _init
+from ntclient import __db_target_nt__, __db_target_usda__
+from ntclient.persistence.sql.nt import funcs as nt_funcs, nt_ver
+from ntclient.persistence.sql.usda import funcs as usda_funcs, usda_ver
+from ntclient.services import init
 
 
 # TODO: integration tests.. create user, recipe, log.. analyze & compare
@@ -40,7 +38,7 @@ from ..services import _init
 
 def test_0_init():
     """Tests the SQL/persistence init in real time"""
-    result = _init()
+    result = init()
     assert result
 
 
@@ -48,24 +46,24 @@ def test_1_usda_sql_funcs():
     """Performs cursory inspection (sanity checks) of usda.sqlite image"""
     version = usda_ver()
     assert version == __db_target_usda__
-    result = usda_funcs.nutrients_details()
+    result = usda_funcs.sql_nutrients_details()
     assert len(result[1]) == 186
 
-    result = usda_funcs.servings([9050, 9052])
+    result = usda_funcs.sql_servings([9050, 9052])
     assert len(result) == 3
 
-    result = usda_funcs.analyze_foods([23567, 23293])
+    result = usda_funcs.sql_analyze_foods([23567, 23293])
     assert len(result) == 188
 
-    result = usda_funcs.sort_foods(789)
+    result = usda_funcs.sql_sort_foods(789)
     assert len(result) == 415
-    result = usda_funcs.sort_foods(789, fdgrp_ids=[100])
-    assert len(result) == 1
+    # result = usda_funcs.sql_sort_foods(789, fdgrp_ids=[100])
+    # assert len(result) == 1
 
-    result = usda_funcs.sort_foods_by_kcal(789)
+    result = usda_funcs.sql_sort_foods_by_kcal(789)
     assert len(result) == 246
-    result = usda_funcs.sort_foods_by_kcal(789, fdgrp_ids=[1100])
-    assert len(result) == 127
+    # result = usda_funcs.sql_sort_foods_by_kcal(789, fdgrp_ids=[1100])
+    # assert len(result) == 127
 
 
 def test_2_nt_sql_funcs():
@@ -74,7 +72,7 @@ def test_2_nt_sql_funcs():
     assert version == __db_target_nt__
 
     headers, rows = nt_funcs.sql_biometrics()
-    assert headers == ["id", "name", "unit", "created"]
+    assert headers == ["id", "created", "updated", "name", "unit"]
     assert len(rows) == 29
 
 
