@@ -13,9 +13,12 @@ COLOR_CRIT = Fore.RED
 
 THRESH_OVER = 1.9
 # COLOR_OVER = Fore.LIGHTBLACK_EX
-COLOR_OVER = Fore.LIGHTMAGENTA_EX
+# COLOR_OVER = Fore.LIGHTMAGENTA_EX
+COLOR_OVER = Fore.MAGENTA
 
-COLOR_DEFAULT = Fore.BLUE
+# COLOR_DEFAULT = Fore.BLUE
+# COLOR_DEFAULT = Fore.LIGHTBLUE_EX
+COLOR_DEFAULT = Fore.LIGHTCYAN_EX
 
 SEARCH_LIMIT = 150
 FOOD_NAME_TRUNC = 200
